import request from '@/utils/request'

// 查询个人页列表
export function listTemplate(query) {
  return request({
    url: '/system/personal/template/list',
    method: 'get',
    params: query
  })
}

// 查询个人页详细
export function getTemplate(id) {
  return request({
    url: '/system/personal/template/' + id,
    method: 'get'
  })
}

// 新增个人页
export function addTemplate(data) {
  return request({
    url: '/system/personal/template',
    method: 'post',
    data: data
  })
}

// 修改个人页
export function updateTemplate(data) {
  return request({
    url: '/system/personal/template',
    method: 'put',
    data: data
  })
}

// 删除个人页
export function delTemplate(id) {
  return request({
    url: '/system/personal/template/' + id,
    method: 'delete'
  })
}

// 导出个人页
export function exportTemplate(query) {
  return request({
    url: '/system/personal/template/export',
    method: 'get',
    params: query
  })
}


// 是否启用修改
export function changeEnable(id, enable) {
  const data = {
    id,
    enable
  }
  return request({
    url: '/system/personal/template/changeEnable',
    method: 'put',
    data: data
  })
}